Summary:        RADIUS proxy that also supports TLS (RadSec)
Name:		radsecproxy
Version:	1.6.6
Release:	arnes.1%{?dist}
Autoreqprov:    on
Group:          Productivity/Networking/Radius
License:	GPL-2+
URL:		http://software.uninett.no/radsecproxy/
Source0:	%{name}-%{version}.tar.xz
Source1:	%{name}.init
Source2:	%{name}-rpmlintrc
Source3:	%{name}-stats.sh
Source4:	%{name}.service
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  openssl-devel patch

%if 0%{?suse_version} > 1140
%define systemd yes
%define suse yes
%endif

%if 0%{?centos} >= 7
%define systemd yes
%define rhel yes
%endif

%if 0%{?systemd:1} 
BuildRequires:	systemd
%{?systemd_requires}
%endif

%description
radsecproxy is a generic RADIUS proxy that in addition to to usual RADIUS UDP
transport, also supports TLS (RadSec). The aim is for the proxy to have
sufficient features to be flexible, while at the same time to be small,
efficient and easy to configure.

%prep
%setup -n %{name}-%{version}

%build
# set DOCBOOK2X_MAN to get extra man page
%configure --enable-fticks --sysconfdir=/etc
make %{?_smp_mflags}

%install
# copy new config file
mkdir -p %{buildroot}/etc
install -D -m 640 radsecproxy.conf-example %{buildroot}/etc/radsecproxy.conf
# copy scripts
mkdir -p %{buildroot}/%{_bindir}
install -D -m 755 tools/naptr-eduroam.sh %{buildroot}/%{_bindir}
install -D -m 755 tools/radsec-dynsrv.sh %{buildroot}/%{_bindir}
install -D -m 755 %{SOURCE3} %{buildroot}/%{_bindir}/radsecproxy-stats.sh
# logfile as ghost file
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/log/
touch $RPM_BUILD_ROOT%{_localstatedir}/log/radsecproxy.log

# install systemd service if available
%if 0%{?systemd:1}
install -D -m 644 %{SOURCE4} %{buildroot}/%{_unitdir}/radsecproxy.service
%else
# copy and symlink the SysV init script on Suse:
mkdir -p %{buildroot}/%{_initddir}
install -D -m 755 %{SOURCE1} %{buildroot}/%{_initddir}/radsecproxy
mkdir -p %{buildroot}/%{_sbindir}
ln -sf %{_initrddir}/radsecproxy %{buildroot}%{_sbindir}/rcradsecproxy
%endif

#create radsecproxy.conf.d directory
install -d -m 750 %{buildroot}/etc/radsecproxy.conf.d/

%makeinstall

######################################33
#suse scripts
%if 0%{?suse:1}
%pre
%if 0%{?systemd:1} 
%service_add_pre radsecproxy.service
%endif
# create radsecd user, if it doesn't exist -- share with freeradius
getent group  radsecd >/dev/null || /usr/sbin/groupadd -r radsecd > /dev/null 2>&1
getent passwd radsecd >/dev/null || /usr/sbin/useradd  -r -g radsecd -c "radsecproxy ouser" -d / -M -s /sbin/nologin radsecd > /dev/null 2>&1
exit 0

%post
%if 0%{?systemd:1} 
%service_add_post radsecproxy.service
%endif

# 2012-05-16 only on update inform the admin:
if [ $1 -eq 2 ]
then
	echo "-----------------------------------------------"
	echo "Please note that the default secret has changed"
	echo "in version 1.6 from \"mysecret\" to \"radsec\"!"
	echo "Please, check your configuration!"
	echo "(RADSECPROXY-19 / draft-ietf-radext-radsec-08)"
	echo "-----------------------------------------------"
fi

%preun
%if 0%{?systemd:1} 
%service_del_preun radsecproxy.service
%endif
%stop_on_removal radsecproxy

%postun
%if 0%{?systemd:1} 
%service_del_postun radsecproxy.service
%endif
%insserv_cleanup
%restart_on_update
%endif #suse scripts


######################################33
#rhel scripts
%if 0%{?rhel:1}

%pre
# create radsecd user, if it doesn't exist -- share with freeradius
getent group  radsecd >/dev/null || /usr/sbin/groupadd -r radsecd > /dev/null 2>&1
getent passwd radsecd >/dev/null || /usr/sbin/useradd  -r -g radsecd -c "radsecproxy user" -d / -M  -s /sbin/nologin radsecd > /dev/null 2>&1
exit 0

%post
%systemd_post radsecproxy.service

%preun
%systemd_preun radsecproxy.service

%postun
%systemd_postun_with_restart radsecproxy.service
if [ $1 -eq 0 ]; then # remove user on uninstall
  getent passwd radsecd >/dev/null && /usr/sbin/userdel  radsecd > /dev/null 2>&1
  getent group  radsecd >/dev/null && /usr/sbin/groupdel radsecd > /dev/null 2>&1
fi
exit 0

%endif #rhel scripts


%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%files
%defattr(-, root, root)
%doc COPYING NEWS AUTHORS ChangeLog LICENSE THANKS radsecproxy.conf-example
%attr(640,root,radsecd) %config(noreplace) %{_sysconfdir}/radsecproxy.conf
%attr(750,root,radsecd) %dir %{_sysconfdir}/radsecproxy.conf.d
#%ghost %attr(640,root,radsecd) %config(noreplace) %{_sysconfdir}/radsecproxy.conf.d/*.conf
%{_sbindir}/radsecproxy
%{_bindir}/radsecproxy-conf
%doc %{_mandir}/man1/*
%doc %{_mandir}/man5/*
%{_bindir}/radsec-dynsrv.sh
%{_bindir}/naptr-eduroam.sh
%{_bindir}/radsecproxy-stats.sh
%ghost %{_localstatedir}/log/radsecproxy.log

%if 0%{?systemd:1} 
%{_unitdir}/radsecproxy.service
%else
%{_initddir}/radsecproxy
%{_sbindir}/rcradsecproxy
%endif

%changelog
* Mon Mar 23 2015 Rok Papež <rok.papez@arnes.si> 1.6.6
- updated to 1.6.6
- added support for CentOS 7
- run radsecproxy as user radsecd
* Fri Jun 22 2012 Sven Uebelacker <sven@uebelacker.net> 1.6
- correcting license to GPL-2+ due to rpmlint "invalid-license Artistic License"
* Wed May 16 2012 Sven Uebelacker <sven@uebelacker.net> 1.6
- adding post-install warning about new default secret
  (RADSECPROXY-19 / draft-ietf-radext-radsec-08)
- removing "restart_on_update" feature because of the above
- explicitly naming config file in sysV script
- update to version 1.6
  + The default shared secret for TLS and DTLS connections change from "mysecret" to "radsec"
  + Preliminary support for DynamicLookupCommand
  + Improved F-Ticks logging
  + Stop the autoconfery from warning
  + Address family (IPv4 or IPv6) can now be specified
  + Don't crash on failing DynamicLookupCommand scripts
* Thu Jan 12 2012 Sven Uebelacker <sven@uebelacker.net> 1.5
- adding systemd service for openSUSE 12.1
* Wed Dec 21 2011 Sven Uebelacker <sven@uebelacker.net> 1.5
- adding radsecproxy-stats.sh
* Mon Oct 17 2011 Sven Uebelacker <sven@uebelacker.net> 1.5
- update to version 1.5
  + Support for F-Ticks logging
  + New binary radsecproxy-hash (but not yet compiling)
  + catgconf renamed to radsecproxy-conf
  + new scripts: naptr-eduroam.sh and radsec-dynsrv.sh
* Fri Aug 19 2011 Sven Uebelacker <sven@uebelacker.net> 1.4.3
- Bug fixes: Debug printout issue
* Mon Apr 18 2011 Sven Uebelacker <sven@uebelacker.net> 1.4.2
- adding SysV init script plus symlink and config example file
* Thu Dec  2 2010 Sven Uebelacker <sven@uebelacker.net> 1.4.2
- Update to 1.4.2 release
* Wed Jun 23 2010 Sven Uebelacker <sven@uebelacker.net> 1.4
- Update to 1.4 release
  Fri Sep 21 2007 Peter Nixon
- Update to 1.0 release
  Wed Jul 25 2007 Peter Nixon
- Initial rpm package
